@@ -1,10 +1,10 @@
-__version__ = "0.1.14"
+__version__ = "0.1.15"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.14)'
+__git_branch__ = '(detached from v0.1.15)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'dd890eabc3d0a725722819a8b91a6c5e1c6c7f22'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '369e5b7e3fedf638008202527dd3738d674e9bca'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
